@@ -52,3 +52,7 @@ def find_excel_data(search_key: str, target_dir: str):
 # @except_dec()
 def split_excel_by_column(filepath: str, column: int, worksheet_name: str = None):
     mainExcel.split_excel_by_column(filepath, column, worksheet_name)
+
+
+def excel2pdf(excel_path, pdf_path):
+    mainExcel.excel2pdf(excel_path, pdf_path)
